"use strict";

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _pvutils = require("pvutils");

var _utils = require("./utils.js");

var _Extension = require("./Extension.js");

var _Extension2 = _interopRequireDefault(_Extension);

var _BaseClass = require("./BaseClass.js");

var _BaseClass2 = _interopRequireDefault(_BaseClass);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

//**************************************************************************************
class SignedCertificateTimestampDataV2 extends _BaseClass2.default {
	//**********************************************************************************
	/**
  * Constructor for SignedCertificateTimestampDataV2 class
  * @param {Object} [parameters={}]
  * @property {Object} [schema] asn1js parsed value
  */
	constructor(parameters = {}) {
		super(parameters);

		//region Internal properties of the object
		/**
   * @type {String}
   * @description logID OID representing used Certificate Transparency Log
   */
		this.logID = (0, _pvutils.getParametersValue)(parameters, "logID", SignedCertificateTimestampDataV2.constants("logID"));
		/**
   * @type {Date}
   * @description timestamp
   */
		this.timestamp = (0, _pvutils.getParametersValue)(parameters, "timestamp", SignedCertificateTimestampDataV2.constants("timestamp"));
		/**
   * @type {Array.<Extension>}
   * @description extensions
   */
		this.extensions = (0, _pvutils.getParametersValue)(parameters, "extensions", SignedCertificateTimestampDataV2.constants("extensions"));
		/**
   * @type {ArrayBuffer}
   * @description signature
   */
		this.signature = (0, _pvutils.getParametersValue)(parameters, "signature", SignedCertificateTimestampDataV2.constants("signature"));
		//endregion
	}
	//**********************************************************************************
	/**
  * Return value for a constant by name
  * @param {string} name String name for a constant
  */
	static constants(name) {
		switch (name) {
			case "logID":
				return "";
			case "timestamp":
				return new Date();
			case "extensions":
				return [];
			case "signature":
				return new ArrayBuffer(0);
			default:
				throw new Error(`Invalid constant name for SignedCertificateTimestampDataV2 class: ${name}`);
		}
	}
	//**********************************************************************************
	/**
  * Convert SeqStream data into current class
  * @param {!SeqStream} stream
  */
	fromStream(stream) {
		this.logID = _utils.utils.getOID(stream, "SignedCertificateTimestampDataV2");

		this.timestamp = new Date(_utils.utils.getUint64(stream));

		let extensionsCount = stream.getUint16();

		while (extensionsCount) {
			this.extensions.push(new _Extension2.default({ stream }));
			extensionsCount--;
		}

		const signatureLength = stream.getUint16();

		this.signature = new Uint8Array(stream.getBlock(signatureLength)).buffer.slice(0);
	}
	//**********************************************************************************
	/**
  * Convert current object to SeqStream data
  * @param {!SeqStream} stream
  * @returns {boolean} Result of the function
  */
	toStream(stream) {
		_utils.utils.appendOID(this.logID, stream);
		_utils.utils.appendUint64(this.timestamp.valueOf(), stream);

		stream.appendUint16(this.extensions.length);

		if (this.extensions.length) {
			var _iteratorNormalCompletion = true;
			var _didIteratorError = false;
			var _iteratorError = undefined;

			try {
				for (var _iterator = this.extensions[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
					const extension = _step.value;

					extension.toStream(stream);
				}
			} catch (err) {
				_didIteratorError = true;
				_iteratorError = err;
			} finally {
				try {
					if (!_iteratorNormalCompletion && _iterator.return) {
						_iterator.return();
					}
				} finally {
					if (_didIteratorError) {
						throw _iteratorError;
					}
				}
			}
		}

		stream.appendUint16(this.signature.byteLength);
		stream.appendView(new Uint8Array(this.signature));

		return true;
	}
	//**********************************************************************************
}
exports.default = SignedCertificateTimestampDataV2; //**************************************************************************************
//# sourceMappingURL=SignedCertificateTimestampDataV2.js.map