"use strict";

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _pvutils = require("pvutils");

var _utils = require("./utils.js");

var _TreeHeadDataV = require("./TreeHeadDataV2.js");

var _TreeHeadDataV2 = _interopRequireDefault(_TreeHeadDataV);

var _BaseClass = require("./BaseClass.js");

var _BaseClass2 = _interopRequireDefault(_BaseClass);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

//**************************************************************************************
class SignedTreeHeadDataV2 extends _BaseClass2.default {
	//**********************************************************************************
	/**
  * Constructor for SignedTreeHeadDataV2 class
  * @param {Object} [parameters={}]
  * @property {Object} [schema] asn1js parsed value
  */
	constructor(parameters = {}) {
		super(parameters);

		//region Internal properties of the object
		/**
   * @type {String}
   * @description logID
   */
		this.logID = (0, _pvutils.getParametersValue)(parameters, "logID", SignedTreeHeadDataV2.constants("logID"));
		/**
   * @type {TreeHeadDataV2}
   * @description treeHead
   */
		this.treeHead = (0, _pvutils.getParametersValue)(parameters, "treeHead", SignedTreeHeadDataV2.constants("treeHead"));
		/**
   * @type {ArrayBuffer}
   * @description signature
   */
		this.signature = (0, _pvutils.getParametersValue)(parameters, "signature", SignedTreeHeadDataV2.constants("signature"));
		//endregion
	}
	//**********************************************************************************
	/**
  * Return value for a constant by name
  * @param {string} name String name for a constant
  */
	static constants(name) {
		switch (name) {
			case "logID":
				return "";
			case "treeHead":
				return new _TreeHeadDataV2.default();
			case "signature":
				return new ArrayBuffer(0);
			default:
				throw new Error(`Invalid constant name for SignedTreeHeadDataV2 class: ${name}`);
		}
	}
	//**********************************************************************************
	/**
  * Convert SeqStream data into current class
  * @param {!SeqStream} stream
  */
	fromStream(stream) {
		this.logID = _utils.utils.getOID(stream, "SignedTreeHeadDataV2");

		this.treeHead = new _TreeHeadDataV2.default({ stream });

		const signatureLength = stream.getUint16();

		this.signature = new Uint8Array(stream.getBlock(signatureLength)).buffer.slice(0);
	}
	//**********************************************************************************
	/**
  * Convert current object to SeqStream data
  * @param {!SeqStream} stream
  * @returns {boolean} Result of the function
  */
	toStream(stream) {
		_utils.utils.appendOID(this.logID, stream);

		this.treeHead.toStream(stream);

		stream.appendUint16(this.signature.byteLength);
		stream.appendView(new Uint8Array(this.signature));

		return true;
	}
	//**********************************************************************************
}
exports.default = SignedTreeHeadDataV2; //**************************************************************************************
//# sourceMappingURL=SignedTreeHeadDataV2.js.map