"use strict";

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _pvutils = require("pvutils");

var _utils = require("./utils.js");

var _BaseClass = require("./BaseClass.js");

var _BaseClass2 = _interopRequireDefault(_BaseClass);

var _Extension = require("./Extension.js");

var _Extension2 = _interopRequireDefault(_Extension);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

//**************************************************************************************
class TreeHeadDataV2 extends _BaseClass2.default {
	//**********************************************************************************
	/**
  * Constructor for TreeHeadDataV2 class
  * @param {Object} [parameters={}]
  * @property {Object} [schema] asn1js parsed value
  */
	constructor(parameters = {}) {
		super(parameters);

		//region Internal properties of the object
		/**
   * @type {Date}
   * @description timestamp
   */
		this.timestamp = (0, _pvutils.getParametersValue)(parameters, "timestamp", TreeHeadDataV2.constants("timestamp"));
		/**
   * @type {Number}
   * @description treeSize
   */
		this.treeSize = (0, _pvutils.getParametersValue)(parameters, "treeSize", TreeHeadDataV2.constants("treeSize"));
		/**
   * @type {ArrayBuffer}
   * @description rootHash
   */
		this.rootHash = (0, _pvutils.getParametersValue)(parameters, "rootHash", TreeHeadDataV2.constants("rootHash"));
		/**
   * @type {Array.<Extension>}
   * @description extensions
   */
		this.extensions = (0, _pvutils.getParametersValue)(parameters, "extensions", TreeHeadDataV2.constants("extensions"));
		//endregion
	}
	//**********************************************************************************
	/**
  * Return value for a constant by name
  * @param {string} name String name for a constant
  */
	static constants(name) {
		switch (name) {
			case "timestamp":
				return new Date();
			case "treeSize":
				return 0;
			case "rootHash":
				return new ArrayBuffer(0);
			case "extensions":
				return [];
			default:
				throw new Error(`Invalid constant name for TreeHeadDataV2 class: ${name}`);
		}
	}
	//**********************************************************************************
	/**
  * Convert SeqStream data into current class
  * @param {!SeqStream} stream
  */
	fromStream(stream) {
		this.timestamp = new Date(_utils.utils.getUint64(stream));
		this.treeSize = _utils.utils.getUint64(stream);

		const hashLength = stream.getBlock(1)[0];
		this.rootHash = new Uint8Array(stream.getBlock(hashLength)).buffer.slice(0);

		let extensionsCount = stream.getUint16();

		while (extensionsCount) {
			this.extensions.push(new _Extension2.default({ stream }));
			extensionsCount--;
		}
	}
	//**********************************************************************************
	/**
  * Convert current object to SeqStream data
  * @param {!SeqStream} stream
  * @returns {boolean} Result of the function
  */
	toStream(stream) {
		_utils.utils.appendUint64(this.timestamp.valueOf(), stream);
		_utils.utils.appendUint64(this.treeSize, stream);

		stream.appendChar(this.rootHash.byteLength);
		stream.appendView(new Uint8Array(this.rootHash));

		stream.appendUint16(this.extensions.length);

		if (this.extensions.length) {
			var _iteratorNormalCompletion = true;
			var _didIteratorError = false;
			var _iteratorError = undefined;

			try {
				for (var _iterator = this.extensions[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
					const extension = _step.value;

					extension.toStream(stream);
				}
			} catch (err) {
				_didIteratorError = true;
				_iteratorError = err;
			} finally {
				try {
					if (!_iteratorNormalCompletion && _iterator.return) {
						_iterator.return();
					}
				} finally {
					if (_didIteratorError) {
						throw _iteratorError;
					}
				}
			}
		}

		return true;
	}
	//**********************************************************************************
}
exports.default = TreeHeadDataV2; //**************************************************************************************
//# sourceMappingURL=TreeHeadDataV2.js.map